summaryrefslogtreecommitdiffstats
path: root/src/config/mod.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/config/mod.rs')
-rw-r--r--src/config/mod.rs8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/config/mod.rs b/src/config/mod.rs
index 6e68283..f29ece7 100644
--- a/src/config/mod.rs
+++ b/src/config/mod.rs
@@ -49,11 +49,11 @@ const SET_COMPLETIONS: [&str; 8] = [
#[derive(Debug, Clone, Deserialize)]
#[serde(default)]
pub struct Config {
/// Openai api key
pub api_key: Option<String>,
/// Openai organization id
pub organization_id: Option<String>,
- /// Openai model
+ /// OpenAI model
#[serde(rename(serialize = "model", deserialize = "model"))]
pub model_name: Option<String>,
/// What sampling temperature to use, between 0 and 2
@@ -517,7 +517,7 @@ fn create_config_file(config_path: &Path) -> Result<()> {
if !ans {
exit(0);
}
- let api_key = Text::new("Openai API Key:")
+ let api_key = Text::new("OpenAI API Key:")
.prompt()
.map_err(text_map_err)?;
let mut raw_config = format!("api_key: {api_key}\n");
@@ -49,11 +49,11 @@ const SET_COMPLETIONS: [&str; 8] = [
#[serde(default)]
pub struct Config {
- /// Openai api key
+ /// OpenAI api key
pub api_key: Option<String>,
@@ -49,11 +49,11 @@ const SET_COMPLETIONS: [&str; 8] = [
pub api_key: Option<String>,
- /// Openai organization id
+ /// OpenAI organization id
pub organization_id: Option<String>,